@@ -1,5 +1,6 @@
 """An extension to capture amsmath latex environments."""
 import re
+from typing import Callable, Optional
 
 from markdown_it import MarkdownIt
 from markdown_it.common.utils import escapeHtml
@@ -10,7 +11,7 @@ from markdown_it.rules_block import StateBlock
 ENVIRONMENTS = [
     # 3.2 single equation with an automatically gen-erated number
     "equation",
-    # 3.3 variation equation, used for equations that don’t fit on a single line
+    # 3.3 variation equation, used for equations that dont fit on a single line
     "multline",
     # 3.5 a group of consecutive equations when there is no alignment desired among them
     "gather",
@@ -46,7 +47,7 @@ ENVIRONMENTS = [
 RE_OPEN = re.compile(r"\\begin\{(" + "|".join(ENVIRONMENTS) + r")([\*]?)\}")
 
 
-def amsmath_plugin(md: MarkdownIt):
+def amsmath_plugin(md: MarkdownIt, *, renderer: Optional[Callable[[str], str]] = None):
     """Parses TeX math equations, without any surrounding delimiters,
     only for top-level `amsmath <https://ctan.org/pkg/amsmath>`__ environments:
 
@@ -57,6 +58,8 @@ def amsmath_plugin(md: MarkdownIt):
         a_2=b_2+c_2-d_2+e_2
         \\end{gather*}
 
+    :param renderer: Function to render content, by default escapes HTML
+
     """
     md.block.ruler.before(
         "blockquote",
@@ -64,6 +67,13 @@ def amsmath_plugin(md: MarkdownIt):
         amsmath_block,
         {"alt": ["paragraph", "reference", "blockquote", "list", "footnote_def"]},
     )
+
+    _renderer = (lambda content: escapeHtml(content)) if renderer is None else renderer
+
+    def render_amsmath_block(self, tokens, idx, options, env):
+        content = _renderer(str(tokens[idx].content))
+        return f'<div class="math amsmath">\n{content}\n</div>\n'
+
     md.add_render_rule("amsmath", render_amsmath_block)
 
 
@@ -82,7 +92,6 @@ def match_environment(string):
 
 
 def amsmath_block(state: StateBlock, startLine: int, endLine: int, silent: bool):
-
     # if it's indented more than 3 spaces, it should be a code block
     if state.sCount[startLine] - state.blkIndent >= 4:
         return False
@@ -111,11 +120,3 @@ def amsmath_block(state: StateBlock, startLine: int, endLine: int, silent: bool)
         token.map = [startLine, line]
 
     return True
-
-
-def render_amsmath_block(self, tokens, idx, options, env):
-    token = tokens[idx]
-    return (
-        '<section class="amsmath">\n<eqn>\n'
-        f"{escapeHtml(token.content)}\n</eqn>\n</section>\n"
-    )
